==> console-plugin-service-3.0-b62-sources.jar: org/glassfish/admingui/plugin/TOCItemInjector.java <==

package org.glassfish.admingui.plugin;

import java.util.ArrayList;
import java.util.List;
import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.config.ConfigInjector;
import org.jvnet.hk2.config.Dom;
import org.jvnet.hk2.config.InjectionTarget;

@Service(name = "tocitem", metadata = "@text=required,@text=datatype:java.lang.String,@text=leaf,@target=required,@target=datatype:java.lang.String,@target=leaf,<tocitem>=collection:org.glassfish.admingui.plugin.TOCItem,target=org.glassfish.admingui.plugin.TOCItem,@expand=required,@expand=datatype:java.lang.String,@expand=leaf")
@InjectionTarget(org.glassfish.admingui.plugin.TOCItem.class)
public class TOCItemInjector
    extends ConfigInjector<org.glassfish.admingui.plugin.TOCItem>
{


    public void inject(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        element_setTOCItems(dom, target);
        attribute_setExpand(dom, target);
        attribute_setTarget(dom, target);
        attribute_setText(dom, target);
    }

    public void injectAttribute(Dom dom, String name, org.glassfish.admingui.plugin.TOCItem target) {
        if ("expand".equals(name)) {
            attribute_setExpand(dom, target);
        }
        if ("target".equals(name)) {
            attribute_setTarget(dom, target);
        }
        if ("text".equals(name)) {
            attribute_setText(dom, target);
        }
    }

    public void injectElement(Dom dom, String name, org.glassfish.admingui.plugin.TOCItem target) {
        if ("tocitem".equals(name)) {
            element_setTOCItems(dom, target);
        }
    }

    public void element_setTOCItems(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        List<Dom> v1 = dom.nodeElements("tocitem");
        if (v1 == null) {
            return ;
        }
        List v2 = new ArrayList<org.glassfish.admingui.plugin.TOCItem>(v1 .size());
        for (Dom v3 : v1) {
            v2 .add(((org.glassfish.admingui.plugin.TOCItem) v3 .get()));
        }
        target.setTOCItems(v2);
    }

    public void attribute_setExpand(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        String v1 = dom.attribute("expand");
        target.setExpand(v1);
    }

    public void attribute_setTarget(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        String v1 = dom.attribute("target");
        target.setTarget(v1);
    }

    public void attribute_setText(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        String v1 = dom.attribute("text");
        target.setText(v1);
    }

}

==> console-plugin-service-3.1-b14-sources.jar: org/glassfish/admingui/plugin/TOCItemInjector.java <==

package org.glassfish.admingui.plugin;

import java.util.ArrayList;
import java.util.List;
import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.config.ConfigInjector;
import org.jvnet.hk2.config.Dom;
import org.jvnet.hk2.config.InjectionTarget;

@Service(name = "tocitem", metadata = "@text=required,@text=datatype:java.lang.String,@text=leaf,@target=required,@target=datatype:java.lang.String,@target=leaf,<tocitem>=collection:org.glassfish.admingui.plugin.TOCItem,target=org.glassfish.admingui.plugin.TOCItem,@expand=required,@expand=datatype:java.lang.String,@expand=leaf")
@InjectionTarget(org.glassfish.admingui.plugin.TOCItem.class)
public class TOCItemInjector
    extends ConfigInjector<org.glassfish.admingui.plugin.TOCItem>
{


    public void inject(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        element_setTOCItems(dom, target);
        attribute_setExpand(dom, target);
        attribute_setTarget(dom, target);
        attribute_setText(dom, target);
    }

    public void injectAttribute(Dom dom, String name, org.glassfish.admingui.plugin.TOCItem target) {
        if ("expand".equals(name)) {
            attribute_setExpand(dom, target);
        }
        if ("target".equals(name)) {
            attribute_setTarget(dom, target);
        }
        if ("text".equals(name)) {
            attribute_setText(dom, target);
        }
    }

    public void injectElement(Dom dom, String name, org.glassfish.admingui.plugin.TOCItem target) {
        if ("tocitem".equals(name)) {
            element_setTOCItems(dom, target);
        }
    }

    public void element_setTOCItems(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        List<Dom> v1 = dom.nodeElements("tocitem");
        if (v1 == null) {
            return ;
        }
        List v2 = new ArrayList<org.glassfish.admingui.plugin.TOCItem>(v1 .size());
        for (Dom v3 : v1) {
            v2 .add(((org.glassfish.admingui.plugin.TOCItem) v3 .get()));
        }
        target.setTOCItems(v2);
    }

    public void attribute_setExpand(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        String v1 = dom.attribute("expand");
        target.setExpand(asBoolean(v1));
    }

    public void attribute_setTarget(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        String v1 = dom.attribute("target");
        target.setTarget(v1);
    }

    public void attribute_setText(Dom dom, org.glassfish.admingui.plugin.TOCItem target) {
        String v1 = dom.attribute("text");
        target.setText(v1);
    }

}
